==> OneHitWonder_4196_v0.025.zip: Interface/AddOns/OneHitWonder/localization_Mobs.lua <==
-- Version : English - sarf
-- Translation by : None

ONEHITWONDER_CREATURE_TYPE_HUMANOID			= "Humanoid";
ONEHITWONDER_CREATURE_TYPE_DEMON			= "Demon";
ONEHITWONDER_CREATURE_TYPE_ELEMENTAL		= "Elemental";
ONEHITWONDER_CREATURE_TYPE_MECHANICAL		= "Mechanical";
ONEHITWONDER_CREATURE_TYPE_BEAST			= "Beast";
ONEHITWONDER_CREATURE_TYPE_NOT_SPECIFIED	= "Not specified";

OneHitWonder_NonDisarmableMobs = {
	"Condemned Monk",
	"Crimson Monk",
	"Scarlet Monk",
	"Dustbelcher Ogre Mage",
	"Scorpid Dunestalker",
	"Glasshide Gazer",
	"Glasshide Petrifier",
	"Fire Roc",
	"Searing Roc",
	"Rapid Blisterpaw",
	"Land Ranger",
	"Voidwalker Minion",
    "Hazzali Swarmer",
    "Hazzali Parasite",
    "Silithid Swarm",
    "Hazzali Wasp",
    "Legashi Satyr",

	"Wavethrasher",
	"Black Brodling",
	"Jadefire Shadowstalker",
	"Bloodpetal Flayer",
	"Bloodpetal Trapper",
	"Bloodpetal Lasher",
	"Bloodpetal Thresher",
	"Primal Ooze",
	"Cloned Ooze",
	"Muculent Ooze",
	"Glutinous Ooze",
	"Hive'Ashi Drone",
	"Tortured Druid",
	"Tortured Sentinel",
	"Xavathras",
	"Jadefire Felsworn",
	"Jadefire Rogue",
	"Jadefire Shadowstalker",
	"Rogue Ice Thistle",
	"Ragged Owlbeast",
	"Winterfall Pathfinder",
	"Winterfall Totemic",
	"Winterfall Den Watcher",
};

OneHitWonder_NonDisarmableMobTypes = {
	ONEHITWONDER_CREATURE_TYPE_BEAST,
	ONEHITWONDER_CREATURE_TYPE_ELEMENTAL
};

OneHitWonder_NonRendableMobTypes = {
	ONEHITWONDER_CREATURE_TYPE_ELEMENTAL,
	ONEHITWONDER_CREATURE_TYPE_MECHANICAL
};

OneHitWonder_PickpocketableMobs = {
	"Cursed Sailor",
	"Cursed Marine",
	"Forsaken Herbalist",
	"Legashi Hellcaller",
	"Legashi Rogue",
	"Jadefire Felsworn",
	"Jadefire Rogue",
	"Jadefire Shadowstalker",
	"Rogue Ice Thistle",
	"Ragged Owlbeast",
	"Winterfall Pathfinder",
	"Winterfall Totemic",
	"Winterfall Den Watcher",
	"Undead Excavator",
	"Skeletal Miner",
	"Undead Dynamiter",
	"Foreman Thistlenettle",
	"Lesser Felguard",
	"Flesh Eater",
	"Rotted One",
	"Skeletal Mage",
	"Skeletal Warrior",
	"Skeletal Horror",
	"Skeletal Fiend",
	"Skeletal Raider",
	"Skeletal Healer",
	"Skeletal Warder",
	"Bone Chewer",
	"Plague Spreader",
	"Brain Eater",
};

OneHitWonder_NonPickpocketableMobs = {	
	"Enraged Foulweald",
	"Nightbane Dark Runner",
	"Nightbane Shadow Weaver",
	"Nightbane Worgen",
	"Nightbane Tainted One",
	"Nightbane Vile Fang",
	"Winterfall Pathfinder",
	"Winterfall Den Watcher",
	"Winterfall Totemic",
	"Giant Yeti",
	"Mountain Yeti"
};

OneHitWonder_PickpocketableTypes = {
	ONEHITWONDER_CREATURE_TYPE_HUMANOID,
	ONEHITWONDER_CREATURE_TYPE_NOT_SPECIFIED
};


if ( GetLocale() == "frFR" ) then
elseif ( GetLocale() == "deDE" ) then
end

==> OneHitWonder_4196_v0.026.zip: Interface/AddOns/OneHitWonder/localization_Mobs.lua <==
-- Version : English - sarf
-- Translation by : None

ONEHITWONDER_CREATURE_TYPE_HUMANOID			= "Humanoid";
ONEHITWONDER_CREATURE_TYPE_DEMON			= "Demon";
ONEHITWONDER_CREATURE_TYPE_ELEMENTAL		= "Elemental";
ONEHITWONDER_CREATURE_TYPE_MECHANICAL		= "Mechanical";
ONEHITWONDER_CREATURE_TYPE_BEAST			= "Beast";
ONEHITWONDER_CREATURE_TYPE_NOT_SPECIFIED	= "Not specified";

OneHitWonder_NonDisarmableMobs = {
	"Condemned Monk",
	"Crimson Monk",
	"Scarlet Monk",
	"Dustbelcher Ogre Mage",
	"Scorpid Dunestalker",
	"Glasshide Gazer",
	"Glasshide Petrifier",
	"Fire Roc",
	"Searing Roc",
	"Rapid Blisterpaw",
	"Land Ranger",
	"Voidwalker Minion",
    "Hazzali Swarmer",
    "Hazzali Parasite",
    "Silithid Swarm",
    "Hazzali Wasp",
    "Legashi Satyr",
	"Wavethrasher",
	"Black Brodling",
	"Jadefire Shadowstalker",
	"Bloodpetal Flayer",
	"Bloodpetal Trapper",
	"Bloodpetal Lasher",
	"Bloodpetal Thresher",
	"Primal Ooze",
	"Cloned Ooze",
	"Muculent Ooze",
	"Glutinous Ooze",
	"Hive'Ashi Drone",
	"Tortured Druid",
	"Tortured Sentinel",
	"Xavathras",
	"Jadefire Felsworn",
	"Jadefire Rogue",
	"Jadefire Shadowstalker",
	"Rogue Ice Thistle",
	"Ragged Owlbeast",
	"Winterfall Pathfinder",
	"Winterfall Totemic",
	"Winterfall Den Watcher",
    "Winterfall Runner",
    "Jaedenar Hound",
    "Jadefire Trickster",
    "Jaedenar Legionnaire",
    "Jaedenar Hunter",
    "Vile Ooze",
    "Deadwood Warrior",
    "Fungal Ooze",
    "Murk Slitherer",
    "Helboar",
    "Shadowsworn Dreadweaver",
    "Felbeast",
    "Rotting Cadaver",
    "Blighted Zombie",
    "Skeletal Terror",
    "Foulmane",
    "Freezing Ghoul",
    "Hate Shrieker",
    "Stitched Horror",
    "Gibbering Ghoul",
    "Felhound",
    "Raging Owlbeast",
    "Ice Thistle Yeti",
    "Crazed Owlbeast",
    "Berserk Owlbeast",
    "Infernal Sentry",
    "Black Broodling",
    "Anguished Highborne",
    "Suffering Highborne",
    "Rage Scar Yeti",
    "Elder Rage Scar",
    "Ferocious Rage Scar"
};

OneHitWonder_NonDisarmableMobTypes = {
	ONEHITWONDER_CREATURE_TYPE_BEAST,
	ONEHITWONDER_CREATURE_TYPE_ELEMENTAL
};

OneHitWonder_NonRendableMobTypes = {
	ONEHITWONDER_CREATURE_TYPE_ELEMENTAL,
	ONEHITWONDER_CREATURE_TYPE_MECHANICAL
};

OneHitWonder_PickpocketableMobs = {
	"Cursed Sailor",
	"Cursed Marine",
	"Forsaken Herbalist",
	"Legashi Hellcaller",
	"Legashi Rogue",
	"Jadefire Felsworn",
	"Jadefire Rogue",
	"Jadefire Shadowstalker",
	"Rogue Ice Thistle",
	"Ragged Owlbeast",
	"Winterfall Pathfinder",
	"Winterfall Totemic",
	"Winterfall Den Watcher",
	"Undead Excavator",
	"Skeletal Miner",
	"Undead Dynamiter",
	"Foreman Thistlenettle",
	"Felguard Sentry",
	"Lesser Felguard",
	"Flesh Eater",
	"Rotted One",
	"Skeletal Mage",
	"Skeletal Warrior",
	"Skeletal Horror",
	"Skeletal Fiend",
	"Skeletal Raider",
	"Skeletal Healer",
	"Skeletal Warder",
	"Bone Chewer",
	"Plague Spreader",
	"Brain Eater",
};

OneHitWonder_NonPickpocketableMobs = {	
	"Enraged Foulweald",
    "Rogue Ice Thistle",
    "Ragged Owlbeast",
    "Raging Owlbeast",
    "Ice Thistle Yeti",
    "Crazed Owlbeast",
    "Berserk Owlbeast",
    "Rage Scar Yeti",
    "Elder Rage Scar",
    "Ferocious Rage Scar",
	"Nightbane Dark Runner",
	"Nightbane Shadow Weaver",
	"Nightbane Worgen",
	"Nightbane Tainted One",
	"Nightbane Vile Fang",
	"Winterfall Pathfinder",
	"Winterfall Den Watcher",
	"Winterfall Totemic",
	"Giant Yeti",
	"Mountain Yeti"
};

OneHitWonder_PickpocketableTypes = {
	ONEHITWONDER_CREATURE_TYPE_HUMANOID,
	ONEHITWONDER_CREATURE_TYPE_NOT_SPECIFIED
};


if ( GetLocale() == "frFR" ) then
elseif ( GetLocale() == "deDE" ) then
end
